@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -16,7 +16,7 @@ extends qw( Pinto::Remote::Action );
 
 #------------------------------------------------------------------------------
 
-with qw( Pinto::Interface::Action::Nop );
+with qw( Pinto::Role::Interface::Action::Nop );
 
 #------------------------------------------------------------------------------
 
@@ -37,7 +37,7 @@ Pinto::Remote::Action::Nop - Run a no-op on a remote repository
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 AUTHOR
 
